==> hellya-6.0.tar.gz: hellya-6.0/README.md <==
# Hellya #

Эта библиотека для программмирования рисунков.


----------


# Использование #

Чтобы создать холст вам нужно:

ширина, высота = 17, 24 - задать ширину и высоту</br>
холст = создать_холст(ширина, высота, белый) - создать непрозрачный холст с заданной шириной и высотой и с белым цветом.</br>

Чтобы нарисовать пиксель вам нужно:

красить_пиксель(холст, 8, 0 , чёрный, на50) - рисует полупрозрачный чёрный пиксель на холсте в координатах x=8 y=0.</br>

Так же можно делать циклы:

повторить(холст, 2, 0, 0, вперёд, зелёный) - рисует 1 пиксель два раза начиная от координат x=0 y=0, двигаясь вперёд по иксу.</br>
повторить(холст, 2, 2, 0, вперёд, зелёный, шаг=2) - рисует 1 пиксель два раза начиная от координат x=3 y=0, двигаясь вперёд пропуская 1 пиксель.</br>
повторить(холст, 2, 0, 2, вниз, зелёный) - рисует 1 пиксель два раза начиная от координат x=0 y=2, двигаясь вниз.</br>
повторить(холст, 2, 4, 6, вверх_вправо, зелёный) - рисует 1 пиксель два раза начиная от координат x=4 y=6, двигаясь вверх вправо.</br>
повторить(холст, 2, 1, 3, вниз_влево, зелёный) - рисует 1 пиксель два раза начиная от координат x=1 y=3, двигаясь вниз влево.</br>

Чтобы сохранить файл вам нужно:

сохранить(холст, в50) - сохраняет холст, но увеличивает картинку в 50 раз сохраняя её качество.</br>

## Аргументы ##

Цвета:

чёрный - чёрный цвет</br>
белый - белый цвет</br>
красный - красный цвет</br>
синий - синий цвет</br>
жёлтый - жёлтый цвет</br>
зелёный - зелёный цвет</br>
коричневый - коричневый цвет</br>
голубой - голубой цвет</br>
светлоголубой - светло-голубой цвет</br>
фиолетовый = фиолетовый цвет</br>
серый = серый цвет</br>

Действия:

вперёд - идти вперёд</br>
вниз - идти вниз</br>
назад - идти назад</br>
вверх - идти вверх</br>
вниз_вправо - идти вниз вправо</br>
вверх_вправо - идти вверх вправо</br>
вниз_влево - идти вниз влево</br>
вверх_влево - идти вверх влево</br>


Степень прозрачности:

полупрозрачный - полупрозрачный пиксель</br>
прозрачный -прозрачный пиксель</br>
на80 - прозрачность пикселя на 80%</br>
на60 - прозрачность пикселя на 60%</br>
на40 - прозрачность пикселя на 40%</br>
на20 - прозрачность пикслея на 20%</br>
непрозрачный - непрозрачный пиксель</br>

Степени увеличения:

в2раза - увеличение изображения в 2 раза</br>
в5раз - увеличение изображения в 5 раз</br>
в10раз - увеличение изображения в 10 раз</br>
в50раз - увеличение изображения в 50 раз</br>
в100раз - увеличение изображения в 100 раз</br>
в200раз - увеличение изображения в 200 раз</br>
в500раз - увеличение изображения в 500 раз</br>
в1000раз - увеличение изображения в 1000 раз</br>


----------


## Разработчик ##
Soviet_Workshop

Сайт: [Soviet_WorkShop](http://soviet-workshop.freemyip.com/)

==> hellya-15.0.tar.gz: hellya-15.0/README.md <==
# Hellya #

Эта библиотека для программмирования рисунков.


----------


# Использование #

Чтобы создать холст вам нужно:

ширина, высота = 17, 24 - задать ширину 17 и высоту 24</br>
холст = создать_холст(ширина, высота, белый) - создать непрозрачный холст с заданной шириной и высотой и с белым цветом.</br>
холст = создать_холст(ширина, высота, пустой) - создать пустой прозрачный холст с заданной шириной и высотой.</br>

Чтобы нарисовать пиксель вам нужно:

красить_пиксель(холст, 8, 0 , чёрный, полупрозрачный) - рисует полупрозрачный чёрный пиксель на холсте в координатах x=8 y=0.</br>
красить_пиксель(холст, 1, 0 , салатовый) - рисует непрозрачный салатовый пиксель на холсте в координатах x=1 y=0.</br>

Так же можно делать циклы:

повторить(холст, 2, 0, 0, вперёд, зелёный) - рисует 1 пиксель два раза начиная от координат x=0 y=0, двигаясь вперёд по иксу.</br>
повторить(холст, 2, 2, 0, вперёд, зелёный, шаг=2) - рисует 1 пиксель два раза начиная от координат x=3 y=0, двигаясь вперёд пропуская 1 пиксель.</br>
повторить(холст, 2, 0, 2, вниз, зелёный, полупрозрачный) - рисует 1 пиксель зелёный полупрозрачный два раза начиная от координат x=0 y=2, двигаясь вниз.</br>
повторить(холст, 2, 4, 6, вверх_вправо, зелёный) - рисует 1 пиксель два раза начиная от координат x=4 y=6, двигаясь вверх вправо.</br>
повторить(холст, 2, 1, 3, вниз_влево, зелёный) - рисует 1 пиксель два раза начиная от координат x=1 y=3, двигаясь вниз влево.</br>

Чтобы сохранить файл вам нужно:

сохранить(холст, в50) - сохраняет холст, но увеличивает картинку в 50 раз сохраняя её качество.</br>
сохранить(холст, в500) - сохраняет холст, но увеличивает картинку в 500 раз сохраняя её качество.</br>

## Аргументы ##

Цвета:

чёрный - чёрный цвет</br>
белый - белый цвет</br>
красный - красный цвет</br>
синий - синий цвет</br>
жёлтый - жёлтый цвет</br>
зелёный - зелёный цвет</br>
коричневый - коричневый цвет</br>
голубой - голубой цвет</br>
светлоголубой - светло-голубой цвет</br>
фиолетовый = фиолетовый цвет</br>
серый = серый цвет</br>
оранжевый = оранжевый цвет</br>
розовый = розовый цвет</br>
салатовый = салатовый цвет</br>
тёмнокрасный = тёмнокрасный цвет</br>
пустой = бесцветный цвет</br>

Действия:

вперёд - идти вперёд</br>
вниз - идти вниз</br>
назад - идти назад</br>
вверх - идти вверх</br>
вниз_вправо - идти вниз вправо</br>
вверх_вправо - идти вверх вправо</br>
вниз_влево - идти вниз влево</br>
вверх_влево - идти вверх влево</br>


Степень прозрачности:

полупрозрачный - полупрозрачный пиксель</br>
прозрачный - прозрачный пиксель</br>
на80 - прозрачность пикселя на 80%</br>
на60 - прозрачность пикселя на 60%</br>
на40 - прозрачность пикселя на 40%</br>
на20 - прозрачность пикслея на 20%</br>
непрозрачный - непрозрачный пиксель</br>

Степени увеличения:

в2раза - увеличение изображения в 2 раза</br>
в5раз - увеличение изображения в 5 раз</br>
в10раз - увеличение изображения в 10 раз</br>
в50раз - увеличение изображения в 50 раз</br>
в100раз - увеличение изображения в 100 раз</br>
в200раз - увеличение изображения в 200 раз</br>
в500раз - увеличение изображения в 500 раз</br>
в1000раз - увеличение изображения в 1000 раз</br>
(Не нужно увеличивать изображение если оно и так большое, эта функция нужна для маленьких изображений)</br>


----------


## Разработчик ##
Soviet_Workshop

Сайт: [Soviet_WorkShop](https://soviet-workshop.freemyip.com/)
